[![PyPI version](https://badge.fury.io/py/qtwirl.svg)](https://badge.fury.io/py/qtwirl) [![Build Status](https://travis-ci.org/alphatwirl/qtwirl.svg?branch=master)](https://travis-ci.org/alphatwirl/qtwirl) [![codecov](https://codecov.io/gh/alphatwirl/qtwirl/branch/master/graph/badge.svg)](https://codecov.io/gh/alphatwirl/qtwirl)

# qtwirl

---
qtwirl (quick-twirl), a one-function interface to alphatwirl
